@@ -1,7 +1,7 @@
 package App::linerange;
 
-our $DATE = '2019-03-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-03-21'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,8 @@ sub linerange {
     my @ranges;
     my @buffer;
     my $bufsize = 0;
-    my $exit_after_line = 0;
+    my $exit_after_linum = 0; # set this to a positive line number if we can optimize
+
     for my $spec2 (split /\s*,\s*/, $args{spec}) {
         $spec2 =~ /\A\s*([+-]?[0-9]+)\s*(?:(\.\.|-|\+)\s*([+-]?[0-9]+)\s*)?\z/
             or return [400, "Invalid line number/range specification '$spec2'"];
@@ -121,17 +122,17 @@ sub linerange {
                         "range specification '$spec2'"];
         } elsif ($ln1 > 0 && $ln2 > 0) {
             push @ranges, $ln1 > $ln2 ? [$ln2, $ln1] : [$ln1, $ln2];
-            unless ($exit_after_line < 0) {
-                $exit_after_line = $ln1 if $exit_after_line < $ln1;
-                $exit_after_line = $ln2 if $exit_after_line < $ln2;
+            unless ($exit_after_linum < 0) {
+                $exit_after_linum = $ln1 if $exit_after_linum < $ln1;
+                $exit_after_linum = $ln2 if $exit_after_linum < $ln2;
             }
         } elsif ($ln1 < 0 && $ln2 < 0) {
             $bufsize = -$ln1 if $bufsize < -$ln1;
             $bufsize = -$ln2 if $bufsize < -$ln2;
             push @ranges, $ln1 > $ln2 ? [$ln1, $ln2] : [$ln2, $ln1];
-            $exit_after_line = -1;
+            $exit_after_linum = -1;
         } else {
-            $exit_after_line = -1;
+            $exit_after_linum = -1;
             if ($ln1 > 0) {
                 $bufsize = -$ln2 if $bufsize < -$ln2;
                 push @ranges, [$ln1, $ln2];
@@ -146,7 +147,7 @@ sub linerange {
     my $linenum = 0;
     while (defined(my $line = <$fh>)) {
         $linenum++;
-        last if $exit_after_line >= 0 && $linenum > $exit_after_line;
+        last if $exit_after_linum >= 0 && $linenum > $exit_after_linum;
         if ($bufsize) {
             push @buffer, $line;
             if (@buffer > $bufsize) { shift @buffer }
@@ -203,7 +204,7 @@ App::linerange - Retrieve line ranges from a filehandle
 
 =head1 VERSION
 
-This document describes version 0.002 of App::linerange (from Perl distribution App-linerange), released on 2019-03-20.
+This document describes version 0.003 of App::linerange (from Perl distribution App-linerange), released on 2019-03-21.
 
 =head1 FUNCTIONS
 
